body {
margin : 0px;
padding : 0px;
text-align : justify;
font-family : Arial, Helvetica, sans-serif;
font-size : 12px;
color : #aaa;
width: 400px;
margin:0 auto;
background:#fff url(/images/bg.jpg) no-repeat top;
		background-attachment:fixed;
		background-size: 100%;
}
img           { border:0; vertical-align:top; }
a             { color:#FFFFFF; text-decoration:none;}
a:hover       { text-decoration:none;}
a:hover img   { position:relative;}

:focus        { outline: 0; }
a {outline:0;}

h1            { font-size:20px; font-weight:normal; line-height:1.3; }
h2            { font-size:18px; font-weight:normal; line-height:1.34;}
h3            { font-size:16px;  line-height:1.375; }
h4            { font-size:14px; font-weight:bold; }
h5            { font-size:12px; font-weight:bold; }
h6            { font-size:11px; font-weight:bold; }
table         { border:0; border-collapse:collapse; border-spacing:0; 
empty-cells:hide; font-size:100%; }
caption,th,td { vertical-align:top; text-align:left; font-weight:normal;}

input[type="text"] {width:262px;margin-left: 0px;border: 1px solid 
#333;background: #111;padding: 5px;color: #aaa;display:block;}
textarea {width:262px;margin-left: 0px;border: 1px solid #333;background: 
#111;padding: 5px;color: #aaa;display:block;}
.button {background: #222;border: 1px solid #333;position: absolute;color: 
#aaa;padding: 5px 10px 5px 10px;margin:0px;margin-top:-30px;margin-left:216px;}
.button:hover {background: #000;}
.tabela {margin-left:  12px;width: 275px;}
.tabela tr{border-top: 1px solid #111;}
td.one{margin-right:2px;}
td.two {text-align:right;color:#eee;}
.tabela tr:hover{background: #111;}
td{padding-top:5px;padding-bottom: 5px;}
.three {padding:0px;border:0px solid #000;margin:0px;}
.four {padding:0px;border-top:0px;border:0px solid #000;margin:0px;}
td.four:hover {background: #000;}
.bk {background: #000;overflow:hidden;width: 300px;min-height: 600px;}
